==> green-core-1.70.1.tgz: package/primitives/listbox/option.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "../../chunks/chunk.QTSIPXV3.js";
var _hidden, _emitSelect, emitSelect_fn;
import { property } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { when } from "lit/directives/when.js";
import { IconCheckmark } from "../../components/icon/icons/checkmark.component";
import { GdsElement } from "../../gds-element";
import { gdsCustomElement, html } from "../../scoping";
import { tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles";
import { watch } from "../../utils/decorators";
import { Focusable } from "../../utils/mixins/focusable";
import style from "./option.styles";
let GdsOption = class extends Focusable(GdsElement) {
  constructor() {
    super();
    __privateAdd(this, _emitSelect);
    __privateAdd(this, _hidden, false);
    this.selected = false;
    this.isPlaceholder = false;
    this.addEventListener("click", __privateMethod(this, _emitSelect, emitSelect_fn));
    this.addEventListener("keydown", (e) => {
      if (e.key !== "Enter" && e.key !== " ")
        return;
      e.preventDefault();
      __privateMethod(this, _emitSelect, emitSelect_fn).call(this, e);
    });
  }
  get hidden() {
    return __privateGet(this, _hidden);
  }
  set hidden(value) {
    const strValue = value.toString();
    __privateSet(this, _hidden, strValue === "true");
    __privateGet(this, _hidden) ? this.setAttribute("inert", "") : this.removeAttribute("inert");
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "option");
    this.updateComplete.then(() => {
      if (this.isPlaceholder) {
        this.hidden = true;
      }
      TransitionalStyles.instance.apply(this, "gds-option");
    });
  }
  get parentElement() {
    return super.parentElement;
  }
  _handlePlaceholderStatusChange() {
    if (this.isPlaceholder) {
      this.hidden = true;
    } else {
      this.hidden = false;
    }
  }
  render() {
    const isMultiple = this.parentElement?.multiple;
    const checkbox = html`
      <span class="checkbox ${classMap({ checked: this.selected })}">
        ${this.selected ? html`<gds-icon-checkmark
              width="10"
              height="10"
              stroke="4"
            ></gds-icon-checkmark>` : ""}
      </span>
    `;
    if (!isMultiple) {
      if (this.selected)
        this.setAttribute("highlighted", "");
      else
        this.removeAttribute("highlighted");
    }
    return html`<div>${when(isMultiple, () => checkbox)} <slot></slot></div>`;
  }
};
_hidden = new WeakMap();
_emitSelect = new WeakSet();
emitSelect_fn = function(e) {
  e.stopPropagation();
  this.dispatchEvent(
    new CustomEvent("gds-select", {
      bubbles: true,
      composed: true,
      detail: {
        value: this.value
      }
    })
  );
};
GdsOption.styles = [tokens, style];
__decorateClass([
  property()
], GdsOption.prototype, "value", 2);
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsOption.prototype, "hidden", 1);
__decorateClass([
  property({
    attribute: "aria-selected",
    reflect: true
  })
], GdsOption.prototype, "selected", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsOption.prototype, "isPlaceholder", 2);
__decorateClass([
  watch("isPlaceholder")
], GdsOption.prototype, "_handlePlaceholderStatusChange", 1);
GdsOption = __decorateClass([
  gdsCustomElement("gds-option", { dependsOn: [IconCheckmark] })
], GdsOption);
export {
  GdsOption
};

==> green-core-1.71.0.tgz: package/primitives/listbox/option.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "../../chunks/chunk.QTSIPXV3.js";
var _hidden, _emitSelect, emitSelect_fn;
import { property } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { when } from "lit/directives/when.js";
import { IconCheckmark } from "../../components/icon/icons/checkmark.component.js";
import { GdsElement } from "../../gds-element.js";
import { gdsCustomElement, html } from "../../scoping.js";
import { tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles.js";
import { watch } from "../../utils/decorators/index.js";
import { Focusable } from "../../utils/mixins/focusable.js";
import style from "./option.styles";
let GdsOption = class extends Focusable(GdsElement) {
  constructor() {
    super();
    __privateAdd(this, _emitSelect);
    __privateAdd(this, _hidden, false);
    this.selected = false;
    this.isPlaceholder = false;
    this.addEventListener("click", __privateMethod(this, _emitSelect, emitSelect_fn));
    this.addEventListener("keydown", (e) => {
      if (e.key !== "Enter" && e.key !== " ")
        return;
      e.preventDefault();
      __privateMethod(this, _emitSelect, emitSelect_fn).call(this, e);
    });
  }
  get hidden() {
    return __privateGet(this, _hidden);
  }
  set hidden(value) {
    const strValue = value.toString();
    __privateSet(this, _hidden, strValue === "true");
    __privateGet(this, _hidden) ? this.setAttribute("inert", "") : this.removeAttribute("inert");
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "option");
    this.updateComplete.then(() => {
      if (this.isPlaceholder) {
        this.hidden = true;
      }
      TransitionalStyles.instance.apply(this, "gds-option");
    });
  }
  get parentElement() {
    return super.parentElement;
  }
  _handlePlaceholderStatusChange() {
    if (this.isPlaceholder) {
      this.hidden = true;
    } else {
      this.hidden = false;
    }
  }
  render() {
    const isMultiple = this.parentElement?.multiple;
    const checkbox = html`
      <span class="checkbox ${classMap({ checked: this.selected })}">
        ${this.selected ? html`<gds-icon-checkmark
              width="10"
              height="10"
              stroke="4"
            ></gds-icon-checkmark>` : ""}
      </span>
    `;
    if (!isMultiple) {
      if (this.selected)
        this.setAttribute("highlighted", "");
      else
        this.removeAttribute("highlighted");
    }
    return html`<div>${when(isMultiple, () => checkbox)} <slot></slot></div>`;
  }
};
_hidden = new WeakMap();
_emitSelect = new WeakSet();
emitSelect_fn = function(e) {
  e.stopPropagation();
  this.dispatchEvent(
    new CustomEvent("gds-select", {
      bubbles: true,
      composed: true,
      detail: {
        value: this.value
      }
    })
  );
};
GdsOption.styles = [tokens, style];
__decorateClass([
  property()
], GdsOption.prototype, "value", 2);
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsOption.prototype, "hidden", 1);
__decorateClass([
  property({
    attribute: "aria-selected",
    reflect: true
  })
], GdsOption.prototype, "selected", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsOption.prototype, "isPlaceholder", 2);
__decorateClass([
  watch("isPlaceholder")
], GdsOption.prototype, "_handlePlaceholderStatusChange", 1);
GdsOption = __decorateClass([
  gdsCustomElement("gds-option", { dependsOn: [IconCheckmark] })
], GdsOption);
export {
  GdsOption
};
